@@ -418,7 +418,7 @@ static clusterKeyVal *cluster_dl_add_key(clusterDistList *dl, char *key,
 /* Add a key, returning a pointer to the entry where passed for easy adding
  * of values to match this key */
 int cluster_dist_add_key(redisCluster *c, HashTable *ht, char *key,
-                          int key_len, clusterKeyVal **kv)
+                          strlen_t key_len, clusterKeyVal **kv)
 {
     int key_free;
     short slot;
@@ -455,7 +455,8 @@ void cluster_dist_add_val(redisCluster *c, clusterKeyVal *kv, zval *z_val
                          TSRMLS_DC)
 {
     char *val;
-    int val_len, val_free;
+    strlen_t val_len;
+    int val_free;
 
     // Serialize our value
     val_free = redis_serialize(c->flags, z_val, &val, &val_len TSRMLS_CC);
@@ -1678,7 +1679,7 @@ PHP_REDIS_API void cluster_sub_resp(INTERNAL_FUNCTION_PARAMETERS, redisCluster *
     /* Multibulk response, {[pattern], type, channel, payload} */
     while(1) {
         /* Arguments */
-        zval *z_type, *z_chan, *z_pat, *z_data;
+        zval *z_type, *z_chan, *z_pat = NULL, *z_data;
         int tab_idx=1, is_pmsg;
 
         // Get the next subscribe response
@@ -2358,9 +2359,9 @@ int mbulk_resp_loop(RedisSock *redis_sock, zval *z_result,
 int mbulk_resp_loop_zipstr(RedisSock *redis_sock, zval *z_result,
                            long long count, void *ctx TSRMLS_DC)
 {
-    char *line, *key;
-    int line_len, key_len;
-    long long idx=0;
+    char *line, *key = NULL;
+    int line_len, key_len = 0;
+    long long idx = 0;
 
     // Our count wil need to be divisible by 2
     if(count % 2 != 0) {
@@ -2401,9 +2402,9 @@ int mbulk_resp_loop_zipstr(RedisSock *redis_sock, zval *z_result,
 int mbulk_resp_loop_zipdbl(RedisSock *redis_sock, zval *z_result,
                            long long count, void *ctx TSRMLS_DC)
 {
-    char *line, *key;
-    int line_len, key_len;
-    long long idx=0;
+    char *line, *key = NULL;
+    int line_len, key_len = 0;
+    long long idx = 0;
 
     // Our context will need to be divisible by 2
     if(count %2 != 0) {
